Struct Dfltrsfr
#[repr(transparent)]pub struct Dfltrsfr(pub u32);Expand description
This register is used to control the reshape and HPF filters.
Tuple Fields
0: u32Implementations
impl Dfltrsfr
impl Dfltrsfr
pub const fn rsfltbyp(&self) -> bool
pub const fn rsfltbyp(&self) -> bool
Reshaper filter bypass Set and cleared by software. This bit is used to bypass the reshape filter and its decimation block. - 0: The reshape filter is not bypassed (Default value) - 1: The reshape filter is bypassed This field can be write-protected, please refer to Section 1.4.15: Register protection for details.
pub const fn set_rsfltbyp(&mut self, val: bool)
pub const fn set_rsfltbyp(&mut self, val: bool)
Reshaper filter bypass Set and cleared by software. This bit is used to bypass the reshape filter and its decimation block. - 0: The reshape filter is not bypassed (Default value) - 1: The reshape filter is bypassed This field can be write-protected, please refer to Section 1.4.15: Register protection for details.
pub const fn rsfltd(&self) -> Rsfltd
pub const fn rsfltd(&self) -> Rsfltd
Reshaper filter decimation ratio Set and cleared by software. This bit is used to select the decimation ratio for the reshape filter - 0: Decimation ratio is 4 (Default value) - 1: Decimation ratio is 1 This field can be write-protected, please refer to Section 1.4.15: Register protection for details.
pub const fn set_rsfltd(&mut self, val: Rsfltd)
pub const fn set_rsfltd(&mut self, val: Rsfltd)
Reshaper filter decimation ratio Set and cleared by software. This bit is used to select the decimation ratio for the reshape filter - 0: Decimation ratio is 4 (Default value) - 1: Decimation ratio is 1 This field can be write-protected, please refer to Section 1.4.15: Register protection for details.
pub const fn hpfbyp(&self) -> bool
pub const fn hpfbyp(&self) -> bool
High-Pass Filter bypass Set and cleared by software. This bit is used to bypass the high-pass filter. - 0: The high pass filter is not bypassed (Default value) - 1: The high pass filter is bypassed This field can be write-protected, please refer to Section 1.4.15: Register protection for details.
pub const fn set_hpfbyp(&mut self, val: bool)
pub const fn set_hpfbyp(&mut self, val: bool)
High-Pass Filter bypass Set and cleared by software. This bit is used to bypass the high-pass filter. - 0: The high pass filter is not bypassed (Default value) - 1: The high pass filter is bypassed This field can be write-protected, please refer to Section 1.4.15: Register protection for details.
pub const fn hpfc(&self) -> Hpfc
pub const fn hpfc(&self) -> Hpfc
High-pass filter cut-off frequency Set and cleared by software. This field is used to select the cut-off frequency of the high-pass filter. FPCM represents the sampling frequency at HPF input. - 00: Cut-off frequency = 0.000625 x FPCM - 01: Cut-off frequency = 0.00125 x FPCM - 10: Cut-off frequency = 0.00250 x FPCM - 11: Cut-off frequency = 0.00950 x FPCM This field can be write-protected, please refer to Section 1.4.15: Register protection for details.
pub const fn set_hpfc(&mut self, val: Hpfc)
pub const fn set_hpfc(&mut self, val: Hpfc)
High-pass filter cut-off frequency Set and cleared by software. This field is used to select the cut-off frequency of the high-pass filter. FPCM represents the sampling frequency at HPF input. - 00: Cut-off frequency = 0.000625 x FPCM - 01: Cut-off frequency = 0.00125 x FPCM - 10: Cut-off frequency = 0.00250 x FPCM - 11: Cut-off frequency = 0.00950 x FPCM This field can be write-protected, please refer to Section 1.4.15: Register protection for details.